/* tslint:disable */
/**
* A parsed λ-expression
*
* This struct is a wrapper around an [`Expression`] to both allow exporting it to JS, and to
* contain functions functions we want to export for the `Exp`, for example [`Exp::to_string`].
*/
export class Exp {
  free(): void;
/**
* Parse and construct a new `Expr`
*
* ```js
* new lambda.Exp(\"(\\\\x.x x) y\");
* new lambda.Exp(2);
* new lambda.Exp(false);
* new lambda.Exp(\"*wtf\");  // Throws exception.
* ```
* @param {any} v 
* @returns {} 
*/
  constructor(v: any);
/**
* See [`Expression::normalize`]
*
* ```js
* let expr = new lambda.Exp(\"(\\\\x.x x) y\");
* let norm = new lambda.Exp(\"y y\");
* console.log(`${norm} = ${expr.normalize(false)}`);
* ```
* @param {boolean} η 
* @returns {Exp} 
*/
  normal(η: boolean): Exp;
/**
* See [`Expression::normalize`]
*
* ```js
* let expr = new lambda.Exp(\"(\\\\x.x x) y\");
* let norm = new lambda.Exp(\"y y\");
* console.log(`${norm} = ${expr.normalize(false)}`);
* ```
* @param {boolean} η 
* @returns {Exp} 
*/
  head_normal(η: boolean): Exp;
/**
* See [`Expression::normalize`]
*
* ```js
* let expr = new lambda.Exp(\"(\\\\x.x x) y\");
* let norm = new lambda.Exp(\"y y\");
* console.log(`${norm} = ${expr.normalize(false)}`);
* ```
* @returns {Exp} 
*/
  weak_normal(): Exp;
/**
* See [`Expression::normalize`]
*
* ```js
* let expr = new lambda.Exp(\"(\\\\x.x x) y\");
* let norm = new lambda.Exp(\"y y\");
* console.log(`${norm} = ${expr.normalize(false)}`);
* ```
* @returns {Exp} 
*/
  weak_head_normal(): Exp;
/**
* See [`std::fmt::Display`]
*
* ```js
* let expr = new lambda.Exp(\"\\\\x.x x\");
* console.log(`${expr}`);
* ```
* @returns {string} 
*/
  toString(): string;
/**
* See `From<Expression> for u64`
*
* ```js
* let two = new lambda.Exp(\"\\\\f.\\\\x.(f (f x))\");
* console.log(`${two.toNumber()}`);
* ```
* @returns {number} 
*/
  toNumber(): number;
/**
* See `From<Expression> for bool`
*
*
* ```js
* let t = new lambda.Exp(\"\\\\a.\\\\b.a\");
* console.log(`${t.toBool()}`);
* ```
* @returns {boolean} 
*/
  toBool(): boolean;
}
